@@ -31,6 +31,7 @@
 #' @S3method rep period
 #' @S3method print period
 #' @S3method format period
+#' @S3method c period
 #' @param ... a list of time units to be included in the period and their amounts. Seconds, minutes, 
 #'   hours, days, weeks, months, and years are supported.
 #' @return a period object
@@ -313,4 +314,8 @@ rep.period <- function(x, ...){
 	attr(y, "class") <- attr(x, "class")
 	y
 }
-	
\ No newline at end of file
+	
+c.period <- function(...){
+	pers <- list(...)
+	do.call(rbind, pers)
+}
